@@ -5,6 +5,7 @@ import dill as pkl
 from os import path
 import pandas as pd
 from dateutil.parser import parse
+import SplatStats.stats as stat
 import SplatStats.parsers as par
 import SplatStats.auxiliary as aux
 pd.options.mode.chained_assignment = None
@@ -37,7 +38,7 @@ class Battle:
         List of awards obtained in the battle.
     """
     ###########################################################################
-    # Battle info
+    # Battle init
     ###########################################################################
     def __init__(self, battleDetail):
         # Battle info ---------------------------------------------------------
@@ -88,7 +89,7 @@ class Battle:
         # Add awards info -----------------------------------------------------
         if (rowMatch.shape[0]>0) and int(rowMatch['self']):
             awards = aux.awardsToStrings(self.awards)
-            for i in range(len(awards)):
+            for i in range(len(awards)): 
                 rowMatch[f'award_{i}'] = awards[i]
         # Return filtered row -------------------------------------------------
         return rowMatch
@@ -135,10 +136,17 @@ class Battle:
         return pDict
     
     def getFullRoster(self):
+        """Generates the dataframe of all players involved in the battle.
+
+        Returns:
+            dataframe: Battle history dataframe with added team column.
+        """        
         (alliedDF, enemyDF) = (
             self.alliedTeam,
             pd.concat(self.enemyTeams, axis=0)
         )
+        alliedDF['Team'] = ['A']*alliedDF.shape[0]
+        enemyDF['Team'] = ['E']*enemyDF.shape[0]
         df = pd.concat([alliedDF, enemyDF], axis=0).reset_index(drop=True)
         return df    
     
@@ -146,55 +154,90 @@ class Battle:
             self, 
             cats=['kill', 'death', 'assist', 'special', 'paint']
         ):
-        dfSum = self.alliedTeam[cats].sum()
-        dfSumDict = dict(dfSum)
-        return dfSumDict
+        """Get allied team total over selected categories.
+
+        Args:
+            cats (list, optional): Categories over which the data will be totaled. Defaults to ['kill', 'death', 'assist', 'special', 'paint'].
+
+        Returns:
+            dict: Allied team totals over the categories.
+        """        
+        tTotal = stat.getTeamTotals(self.alliedTeam, cats=cats)
+        return tTotal
     
     def getEnemiesTotals(
             self, 
             cats=['kill', 'death', 'assist', 'special', 'paint']
         ):
+        """Get enemy teams total over selected categories.
+
+        Args:
+            cats (list, optional): Categories over which the data will be totaled. Defaults to ['kill', 'death', 'assist', 'special', 'paint'].
+
+        Returns:
+            list of dataframes: Enemy team totals over the categories.
+        """         
         teams = self.enemyTeams
-        dfSum = [team[cats].sum() for team in teams]
-        dfSumDict = [dict(team) for team in dfSum]
-        return dfSumDict
+        tTotals = [stat.getTeamTotals(team, cats=cats) for team in teams]
+        return tTotals
     
     def getAlliedRanks(
             self,
-            cats=['kill', 'death', 'assist', 'special', 'paint']
+            cats=['kill', 'death', 'assist', 'special', 'paint'],
+            inverted=['death']
         ):
+        """Returns a dataframe with the rankings of the allied players across categories (higher numbers being better unless in inverted list).
+
+
+        Args:
+            cats (list, optional): Categories over which the data will be totaled. Defaults to ['kill', 'death', 'assist', 'special', 'paint'].
+            inverted (list, optional): In the original rankings more is considered better, this list should contain the categories that should be inverted. Defaults to ['death'].
+
+
+        Returns:
+            dataframe: Allied team ranking dataframe over categories.
+        """        
         team = self.alliedTeam
-        (names, ranks) = (
-            team[['player name', 'player name id']],
-            team[cats].rank(ascending=False).astype(int)
-        )
-        dfRank = pd.concat([names, ranks], axis=1)
-        return dfRank
+        ranks = stat.getTeamRanks(team, cats=cats, inverted=inverted)
+        return ranks
     
     def getEnemiesRanks(
             self,
-            cats=['kill', 'death', 'assist', 'special', 'paint']
+            cats=['kill', 'death', 'assist', 'special', 'paint'],
+            inverted=['death']
         ):
+        """Returns a list of dataframes with the rankings of the enemies players across categories (higher numbers being better unless in inverted list).
+
+        Args:
+            cats (list, optional): Categories over which the data will be totaled. Defaults to ['kill', 'death', 'assist', 'special', 'paint'].
+            inverted (list, optional): In the original rankings more is considered better, this list should contain the categories that should be inverted. Defaults to ['death'].
+
+        Returns:
+            list of dataframes: Enemy teams ranking dataframe over categories.
+        """        
         dfRanks = []
         for team in self.enemyTeams:
-            (names, ranks) = (
-                team[['player name', 'player name id']],
-                team[cats].rank(ascending=False).astype(int)
-            )
-            dfRank = pd.concat([names, ranks], axis=1)
+            dfRank = stat.getTeamRanks(team, cats=cats, inverted=inverted)
             dfRanks.append(dfRank)
         return dfRanks
 
     def getFullRanks(
             self,
-            cats=['kill', 'death', 'assist', 'special', 'paint']
+            cats=['kill', 'death', 'assist', 'special', 'paint'],
+            inverted=['death']
         ):
+        """Returns a dataframe with the rankings of the full roster of players across categories (higher numbers being better unless in inverted list).
+
+
+        Args:
+            cats (list, optional): Categories over which the data will be totaled. Defaults to ['kill', 'death', 'assist', 'special', 'paint'].
+            inverted (list, optional): In the original rankings more is considered better, this list should contain the categories that should be inverted. Defaults to ['death'].
+
+        Returns:
+            dataframe: Full roster ranking dataframe over categories.
+        """        
         df = self.getFullRoster()
-        (names, ranks) = (
-            df[['player name', 'player name id']],
-            df[cats].rank(ascending=False).astype(int)
-        )
-        dfRank = pd.concat([names, ranks], axis=1)
+        dfRank = stat.getTeamRanks(df, cats=cats, inverted=inverted)
         return dfRank
         
     
