@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import pandas as pd
 from tqdm import tqdm
 from termcolor import colored
 from collections import Counter
@@ -164,4 +165,43 @@ class Player:
         (alliesC, enemiesC) = [
             Counter(i).most_common() for i in (allies, enemies)
         ]
-        return {'allies': alliesC, 'enemies': enemiesC}
\ No newline at end of file
+        return {'allies': alliesC, 'enemies': enemiesC}
+    
+    ###########################################################################
+    # Get player rankings
+    ########################################################################### 
+    def getPlayerAlliedRanking(
+            self,
+            cats=['kill', 'death', 'assist', 'special', 'paint']
+        ):
+        (btlRecords, rnks) = (self.battleRecords, [])
+        for btl in btlRecords:
+            df = btl.getAlliedRanks(cats=cats)
+            fltr = df[df['player name'] == self.name]
+            rnks.append(fltr)
+        df = pd.concat(rnks, axis=0).drop(columns=['player name', 'player name id'])
+        # Filter invalid battles and make indexes match -----------------------
+        bHist = self.battlesHistory
+        vIx = list(bHist.index)
+        df = df.iloc[vIx]
+        df = df.set_index(pd.Series(vIx))
+        df['datetime'] = bHist['datetime']
+        return  df
+    
+    def getPlayerFullRanking(
+            self,
+            cats=['kill', 'death', 'assist', 'special', 'paint']
+        ):
+        (btlRecords, rnks) = (self.battleRecords, [])
+        for btl in btlRecords:
+            df = btl.getFullRanks(cats=cats)
+            fltr = df[df['player name'] == self.name]
+            rnks.append(fltr)
+        df = pd.concat(rnks, axis=0).drop(columns=['player name', 'player name id'])
+        # Filter invalid battles and make indexes match -----------------------
+        bHist = self.battlesHistory
+        vIx = list(bHist.index)
+        df = df.iloc[vIx]
+        df = df.set_index(pd.Series(vIx))
+        df['datetime'] = bHist['datetime']
+        return  df
\ No newline at end of file
